# Generated by Django 2.0.9 on 2018-11-19 16:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("cast", "0013_remove_blog_image")]

    operations = [
        migrations.AddField(
            model_name="itunesartwork",
            name="original_height",
            field=models.PositiveIntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="itunesartwork",
            name="original_width",
            field=models.PositiveIntegerField(blank=True, null=True),
        ),
    ]
