# Generated by Django 2.1.3 on 2018-11-09 15:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("cast", "0002_auto_20181109_0640")]

    operations = [
        migrations.AddField(
            model_name="audio",
            name="duration",
            field=models.DurationField(blank=True, null=True),
        )
    ]
