# Generated by Django 2.0.9 on 2018-11-19 16:12

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [("cast", "0012_auto_20181119_1612")]

    operations = [migrations.RemoveField(model_name="blog", name="image")]
