# Generated by Django 2.1.3 on 2018-11-09 12:40

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import model_utils.fields


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("cast", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="Audio",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "created",
                    model_utils.fields.AutoCreatedField(
                        default=django.utils.timezone.now,
                        editable=False,
                        verbose_name="created",
                    ),
                ),
                (
                    "modified",
                    model_utils.fields.AutoLastModifiedField(
                        default=django.utils.timezone.now,
                        editable=False,
                        verbose_name="modified",
                    ),
                ),
                ("original", models.FileField(upload_to="cast_audio/")),
                (
                    "user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={"abstract": False},
        ),
        migrations.AlterField(
            model_name="file",
            name="original",
            field=models.FileField(upload_to="cast_files/"),
        ),
        migrations.AlterField(
            model_name="image",
            name="original",
            field=models.ImageField(
                height_field="original_height",
                upload_to="cast_images/originals",
                width_field="original_width",
            ),
        ),
        migrations.AlterField(
            model_name="video",
            name="original",
            field=models.FileField(upload_to="cast_videos/"),
        ),
        migrations.AlterField(
            model_name="video",
            name="poster",
            field=models.ImageField(
                blank=True, null=True, upload_to="cast_videos/poster/"
            ),
        ),
        migrations.AddField(
            model_name="post",
            name="audios",
            field=models.ManyToManyField(to="cast.Audio"),
        ),
    ]
