{% extends "cast/cast_base.html" %}
{% load static %}

{% block content %}

{{ blog.pk }}
{{ blog.title }}
{% if user.is_authenticated %}
<a href="{% url "cast:post-create" slug=blog.slug %}">Create Arcticle</a>
{% endif %}

<br>
<a href="{% url "cast:post-list" slug=blog.slug %}">articles</a>
{% endblock content %}
